package com.tanpu.community.manager;

import com.tanpu.common.api.CommonResp;
import com.tanpu.common.auth.UserHolder;
import com.tanpu.common.constant.ErrorCodeConstant;
import com.tanpu.community.api.beans.qo.TopicFollowQo;
import com.tanpu.community.api.beans.qo.TopicRankQo;
import com.tanpu.community.api.beans.req.page.Page;
import com.tanpu.community.api.beans.req.topic.TopicSearchReq;
import com.tanpu.community.api.enums.TopicSpecialPermissionEnum;
import com.tanpu.community.dao.entity.community.TopicEntity;
import com.tanpu.community.service.RankService;
import com.tanpu.community.service.TopicService;
import com.tanpu.community.util.PageUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

@Service
public class TopicManager {


    @Autowired
    private TopicService topicService;
    @Autowired
    private RankService rankService;

    @Autowired
    private UserHolder userHolder;

    // 首页-话题标签
    public List<TopicRankQo> getTop4TopicTitles() {
        return rankService.getRankTopicListTop4();
    }


    // 话题搜索列表
    public Page<TopicRankQo> getAllTopicBriefInfo(TopicSearchReq req) {
        // 全量排序，内存分页
        List<TopicRankQo> topicList = rankService.getRankTopicList(req.getSearchKeyword());
        return PageUtils.page(req.getPage(), topicList);
    }

    // 关注话题（讨论区）列表
    public List<TopicFollowQo> getFollowTopicList() {

        String userId = userHolder.getUserId();
        // 全量排序，内存分页
        topicService.queryFollowTopic(userId);


        return null;
    }

    // 话题详情页
    public CommonResp<TopicRankQo> getDetail(String topicId) {


        TopicEntity topicEntity = topicService.queryOnlineTopicById(topicId);
        if (topicEntity == null) {
            return CommonResp.error(ErrorCodeConstant.TOPIC_NOT_FOUND.getCode(), "抱歉！该话题已下线。");
        }

        //
        if (TopicSpecialPermissionEnum.TRUE.getCode().equals(topicEntity.getSpecialPermission()) && !checkPermission(topicId, userHolder.getUserId())) {
            return CommonResp.error(ErrorCodeConstant.TOPIC_PERMISSION_ABORT.getCode(), getPermissionToast(topicId));
        }

        return CommonResp.success(rankService.getTopicDetail(topicId));
    }

    private String getPermissionToast(String topicId) {

        String permission = "专业版会员";

        // return "暂无权限参与此话题～您可联系官方客服 021- 了解详情";
        return "该话题仅限" + permission + "可参与哦~";
    }

    /**
     * 判断用户是否拥有权限（1对1）
     *
     * @param topicId
     * @param userId
     */
    private boolean checkPermission(String topicId, String userId) {

        return true;
    }


}

